@@ -70,17 +70,51 @@ class HyperV:
         logging.debug(f'result: {result}')
         return result
     
-
+    # Проверка наличия папки у виртуальной машины
+    def path_exists(self, vm_name=''):
+        vm_patch=f"{self.storage_root}\{self.env_prefix}\{vm_name}"
+        ps_script =  f'Test-Path -Path "{vm_patch}"'
+        logging.debug(f'ps_script: {ps_script}')
+        r = self.session.run_ps(ps_script)
+        logging.debug(f'status_code: {r.status_code}')
+        logging.debug(f"std_out: {r.std_out.decode('utf-8')}")
+        if 'True' in r.std_out.decode('utf-8'):
+            return True
+        return False
+    
+    # Удаление папки виртуальной машины
+    def path_remove(self, vm_name=''):
+        vm_patch=f"{self.storage_root}\{self.env_prefix}\{vm_name}"
+        ps_script =  f'Remove-Item "{vm_patch}" -Recurse'
+        logging.debug(f'ps_script: {ps_script}')
+        r = self.session.run_ps(ps_script)
+        logging.debug(f'status_code: {r.status_code}')
+        logging.debug(f"std_out: {r.std_out.decode('utf-8')}")
+        if r.status_code == '1':
+            return False
+        return True
+    
+    def vm_exists(self, vm_name=''):
+        ps_script =  f'Get-VM -Name "{ vm_name }"| Select -ExpandProperty Name'
+        logging.debug(f'ps_script: {ps_script}')
+        r = self.session.run_ps(ps_script)
+        logging.debug(f'status_code: {r.status_code}')
+        logging.debug(f"std_out: {r.std_out.decode('utf-8')}")
+        vm_find_name = r.std_out.decode('utf-8').strip()
+        if vm_name == vm_find_name:
+            return True
+        return False
+    
     # Создание виртуалок
-    def import_vm(self, name='', ip='', cpu=1, ram=1, template_name='', vmcx =''):
+    def import_vm(self, vm_name='', cpu=1, ram=1, template_name='', vmcx =''):
         if vmcx == '':
             vmcx = self.get_vmcx
         if template_name == '':
             template_name = self.get_template_name(vmcx)
         
         import_from=f"{self.vm_template_pach}\Virtual Machines\{vmcx}"
-        vm_patch=f"{self.storage_root}\{self.env_prefix}\{self.env_prefix}-{name}"
-        vm_name=f"{self.env_prefix}-{name}_({ip})"
+        vm_patch=f"{self.storage_root}\{self.env_prefix}\{vm_name}"
+        vm_name=f"{vm_name}"
 
         # Генерируем powershell скрипт
         ps_script =  f'''
@@ -104,7 +138,7 @@ class HyperV:
 
     # Включение виртуалок
     def vm_start(self, vms=[]):
-        ps_script = self.gen_job(vms=vms, job='Start-VM')
+        ps_script = self.gen_job(vms_list=vms, job='Start-VM')
         result = self.session.run_ps(ps_script)
         logging.debug(f"result std_out\n{result.std_out.decode('utf-8')}")
         logging.debug(f"result status_code \n{result.status_code}")
