@@ -1,29 +1,31 @@
-import nmap
+import subprocess
 import socket
 
 class Network:
-
     def __init__(
         self,
         network
         )-> None:
 
-        nm = nmap.PortScanner()
-        nm.scan(hosts=network, arguments='-sn -v -n')
-        self.hosts_list = [(x, nm[x]['status']['state']) for x in nm.all_hosts()]
+        cmd = f'fping -g -r 1 {network}'
+        process = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
+        process.wait()
+
+        self.hosts_list = [(x.strip().decode().split(' ')[0], x.strip().decode().split(' ')[2]) for x in process.stdout]
+
 
     @property
     def free(self):
         ip = []
         for host, status in self.hosts_list:
-            if status == 'down': ip.append(host)
+            if status == 'unreachable': ip.append(host)
         return ip
     
     @property
     def busy(self):
         ip = []
         for host, status in self.hosts_list:
-            if status == 'up': ip.append(host)
+            if status == 'alive': ip.append(host)
         return ip
 
 
